# bengali
----------------------------------------------
#### A Python package for Bengali language processing related tasks.
-----------------------------------------------

## Background
<p align= "justify">

```Bengali``` also known as ```Bangla``` is one of the widely used language in the world. This python package is an effort to combine some usefull python tools to work conveniently with Bengali language and computation.
</p>

--------------------------------------------------


## Installation
Install using the following command - 
```bash
pip install bengali
```

Uninstall using the following command - 
```bash
pip uninstall bengali
```

## Getting Started

To use ```bengali``` install it using ```pip```. And make sure you have the required python version in your environment, i.e. ```python >= 3.5```.


## How to Contribute

## Inspiration
